@@ -6,9 +6,10 @@ Created on Wed Jan  5 16:45:12 2022
 """
 import torch
 from prettytable import PrettyTable
-from deep_b_spline_approximation.preprocessing import computeSegmentation,computeSampling,computeSegmentsNormalization,computeSegmentsParametrization,computeRefinement2
-from deep_b_spline_approximation.ppn import PointParametrizationNetwork,PointParametrizationNetworkCNN2
-from deep_b_spline_approximation.kpn import KnotPlacementNetwork
+import os
+from .preprocessing import computeSegmentation,computeSampling,computeSegmentsNormalization,computeSegmentsParametrization,computeRefinement2
+from .ppn import PointParametrizationNetwork,PointParametrizationNetworkCNN2
+from .kpn import KnotPlacementNetwork
 
 class BSplineApproximator:
     
@@ -22,18 +23,19 @@ class BSplineApproximator:
         elif(device == 'cpu'):
             self.device = 'cpu'
         
-        self.path_load_kpn = r"kpn_mlp4.pt"
+        output_dir = os.path.join(os.path.dirname(os.path.realpath(__file__)),'data')
+        
+        self.path_load_kpn = os.path.join(output_dir,'kpn_mlp4.pt')
         
         self.p = 2
         
         #Load point parametrization network
         if(ppn_type == "mlp"):
-            
-            self.path_load_ppn = r"ppn_mlp1.pt"
+            self.path_load_ppn = os.path.join(output_dir,'ppn_mlp1.pt')
             dim, hiddenSize = 200, 1000
             self.ppn = PointParametrizationNetwork(dim,hiddenSize,self.p,device=self.device)
         elif(ppn_type == "cnn"):
-            self.path_load_ppn = r"models\ppn_cnn1.pt"
+            self.path_load_ppn = os.path.join(output_dir,'ppn_cnn1.pt')
             self.ppn = PointParametrizationNetworkCNN2(device=self.device)
             
         checkpoint1 = torch.load(self.path_load_ppn)
@@ -63,7 +65,13 @@ class BSplineApproximator:
         HD_log = torch.zeros(points.shape[0],n_knots+1).to(self.device)
         MSE_log = torch.zeros(points.shape[0],n_knots+1).to(self.device)
         
-        t = PrettyTable(['Sequence of points','Degree of spline function','Hausdorff distance','Mean Squared Error'])
+        t = PrettyTable(['Sequence of points n.','Degree of the spline function','Hausdorff distance','Mean Squared Error'])
+        t.align['Sequence of points n.'] = 'l'
+        t.align['Degree of the spline function'] = 'l'
+        t.align['Hausdorff distance'] = 'l'
+        t.align['Mean Squared Error'] = 'r'
+        t.hrules = 1
+        print(t)
         
         for i,seq_of_points in enumerate(points,0):
             
@@ -109,8 +117,7 @@ class BSplineApproximator:
             
             torch.cuda.empty_cache()
             
-            #print("sequence of points {}, Hausdorff distance: {:0.4f}, Mean Squared Error {:0.4f}".format(i,hd[-1],mse[-1]))
-            t.add_row([i,k,hd[-1],mse[-1]])
-            print(t)
+            t.add_row([i,k,round(hd[-1].item(),3),round(mse[-1].item(),3)])
+            print ("\n".join(t.get_string().splitlines()[-2:]))
             
         return splines,list_of_knots,HD_log,MSE_log
\ No newline at end of file
